#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-value
version:              0.8.3
visibility:           public
id:                   config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
key:                  config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
license:              MIT
copyright:            2015-2016,2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-value
synopsis:             Simple, layout-based value language similar to YAML or JSON
description:
    This package implements a language similar to YAML or JSON but
    with fewer special cases and fewer dependencies. It emphasizes
    layout structure for sections and lists, and requires quotes
    around strings.

category:             Language
abi:                  b8e940c07339edc4a3da38acf2fd02ec
exposed:              True
exposed-modules:      Config Config.Lens Config.Macro Config.Number
hidden-modules:
    Config.Lexer Config.LexerUtils Config.Parser Config.NumberParser
    Config.Tokens Config.Pretty Config.Value

import-dirs:          /usr/lib/ghc-9.6.6/site-local/config-value-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/config-value-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/config-value-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-value
hs-libraries:         HSconfig-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7 pretty-1.1.3.6
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-config-value/html/config-value.haddock

haddock-html:         /usr/share/doc/haskell-config-value/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

